@@ -14,8 +14,13 @@
 
 import unittest
 
+import os
 import sys
-sys.path.extend('..')
+_test_dir = os.path.dirname(os.path.abspath(__file__))
+_code_dir = os.path.dirname(_test_dir)
+if not _code_dir in sys.path:
+    sys.path.insert(1, _code_dir)
+
 import enum
 
 
@@ -79,6 +84,79 @@ class ValuesFixture(object):
                 values[key] = enum.EnumValue(enumtype, i, key)
             params.update(dict(enumtype=enumtype, values=values))
 
+
+class Test_Module(unittest.TestCase):
+    """ Test case for the module """
+
+    def setUp(self):
+        """ Set up test fixtures """
+        from sys import modules
+        self.module = modules['enum']
+
+    def test_author_name_is_string(self):
+        """ Module should have __author_name__ string """
+        mod_author_name = self.module.__author_name__
+        self.failUnless(isinstance(mod_author_name, basestring))
+
+    def test_author_email_is_string(self):
+        """ Module should have __author_email__ string """
+        mod_author_email = self.module.__author_email__
+        self.failUnless(isinstance(mod_author_email, basestring))
+
+    def test_author_is_string(self):
+        """ Module should have __author__ string """
+        mod_author = self.module.__author__
+        self.failUnless(isinstance(mod_author, basestring))
+
+    def test_author_contains_name(self):
+        """ Module __author__ string should contain author name """
+        mod_author = self.module.__author__
+        mod_author_name = self.module.__author_name__
+        self.failUnless(mod_author.startswith(mod_author_name))
+
+    def test_author_contains_email(self):
+        """ Module __author__ string should contain author email """
+        mod_author = self.module.__author__
+        mod_author_email = self.module.__author_email__
+        self.failUnless(mod_author.endswith("<%s>" % mod_author_email))
+
+    def test_date_is_string(self):
+        """ Module should have __date__ string """
+        mod_date = self.module.__date__
+        self.failUnless(isinstance(mod_date, basestring))
+
+    def test_copyright_is_string(self):
+        """ Module should have __copyright__ string """
+        mod_copyright = self.module.__copyright__
+        self.failUnless(isinstance(mod_copyright, basestring))
+
+    def test_copyright_contains_name(self):
+        """ Module __copyright__ string should contain author name """
+        mod_copyright = self.module.__copyright__
+        mod_author_name = self.module.__author_name__
+        self.failUnless(mod_copyright.endswith(mod_author_name))
+
+    def test_copyright_contains_year(self):
+        """ Module __copyright__ string should contain year """
+        mod_copyright = self.module.__copyright__
+        mod_year = self.module.__date__.split('-')[0]
+        self.failUnless(mod_year in mod_copyright)
+
+    def test_license_is_string(self):
+        """ Module should have __license__ string """
+        mod_license = self.module.__license__
+        self.failUnless(isinstance(mod_license, basestring))
+
+    def test_url_is_string(self):
+        """ Module should have __url__ string """
+        mod_url = self.module.__url__
+        self.failUnless(isinstance(mod_url, basestring))
+
+    def test_version_is_string(self):
+        """ Module should have __version__ string """
+        mod_version = self.module.__version__
+        self.failUnless(isinstance(mod_version, basestring))
+
 
 class Test_EnumException(unittest.TestCase):
     """ Test case for the Enum exception classes """
@@ -319,7 +397,8 @@ class Test_Enum(unittest.TestCase, ValuesFixture):
         def test_func(enumtype, params):
             for i, key in enumerate(params['keys']):
                 value = getattr(enumtype, key)
-                self.failUnless(value)
+                test_value = enum.EnumValue(enumtype, i, key)
+                self.failUnlessEqual(test_value, value)
 
         self.iterate_test(test_func)
 
@@ -335,7 +414,8 @@ class Test_Enum(unittest.TestCase, ValuesFixture):
         def test_func(enumtype, params):
             for i, key in enumerate(params['keys']):
                 value = enumtype[i]
-                self.failUnless(value)
+                test_value = enum.EnumValue(enumtype, i, key)
+                self.failUnlessEqual(test_value, value)
 
         self.iterate_test(test_func)
 
